## Summary

Brief description of changes.

## Type of Change

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update

## Checklist

- [ ] My code follows the project's style guidelines
- [ ] I have run `make lint` and fixed any issues
- [ ] I have added tests that prove my fix/feature works
- [ ] All new and existing tests pass (`make ci`)
- [ ] I have updated documentation as needed

## Test Plan

Describe how you tested these changes.

## Related Issues

Fixes #(issue number)
